agent-push-kit.api.events


get-eventclj

(get-event organizationId eventId)

Get one event including metadata

Get one event including metadata
raw docstring

get-event-with-http-infoclj

(get-event-with-http-info organizationId eventId)

Get one event including metadata

Get one event including metadata
raw docstring

list-eventsclj

(list-events organizationId)
(list-events organizationId optional-params)

List a paginated inbox

List a paginated inbox
raw docstring

list-events-with-http-infoclj

(list-events-with-http-info organizationId)
(list-events-with-http-info organizationId
                            {:keys [service type search cursor limit]})

List a paginated inbox

List a paginated inbox
raw docstring

list-notification-typesclj

(list-notification-types organizationId)
(list-notification-types organizationId optional-params)

List distinct notification types

List distinct notification types
raw docstring

list-notification-types-with-http-infoclj

(list-notification-types-with-http-info organizationId)
(list-notification-types-with-http-info organizationId {:keys [serviceId]})

List distinct notification types

List distinct notification types
raw docstring

list-servicesclj

(list-services organizationId)

List services discovered from ingested events

List services discovered from ingested events
raw docstring

list-services-with-http-infoclj

(list-services-with-http-info organizationId)

List services discovered from ingested events

List services discovered from ingested events
raw docstring

search-eventsclj

(search-events organizationId search-events-input)

Search events with a validated Boolean filter tree

Search events with a validated Boolean filter tree
raw docstring

search-events-with-http-infoclj

(search-events-with-http-info organizationId search-events-input)

Search events with a validated Boolean filter tree

Search events with a validated Boolean filter tree
raw docstring

send-eventclj

(send-event send-event-input)

Send an event using an application ingestion key

Send an event using an application ingestion key
raw docstring

send-event-as-userclj

(send-event-as-user organizationId send-event-input)

Send an event as an authenticated user or agent

Send an event as an authenticated user or agent
raw docstring

send-event-as-user-with-http-infoclj

(send-event-as-user-with-http-info organizationId send-event-input)

Send an event as an authenticated user or agent

Send an event as an authenticated user or agent
raw docstring

send-event-with-http-infoclj

(send-event-with-http-info send-event-input)

Send an event using an application ingestion key

Send an event using an application ingestion key
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries