agent-push-kit.api.preferences


list-preferencesclj

(list-preferences organizationId)

List service defaults and exact-type overrides

List service defaults and exact-type overrides
raw docstring

list-preferences-with-http-infoclj

(list-preferences-with-http-info organizationId)

List service defaults and exact-type overrides

List service defaults and exact-type overrides
raw docstring

remove-type-preferenceclj

(remove-type-preference serviceId type)

Remove an exact-type override so it inherits the service default

Remove an exact-type override so it inherits the service default
raw docstring

remove-type-preference-with-http-infoclj

(remove-type-preference-with-http-info serviceId type)

Remove an exact-type override so it inherits the service default

Remove an exact-type override so it inherits the service default
raw docstring

set-service-preferenceclj

(set-service-preference serviceId set-enabled-input)

Enable or disable pushes for a service by default

Enable or disable pushes for a service by default
raw docstring

set-service-preference-with-http-infoclj

(set-service-preference-with-http-info serviceId set-enabled-input)

Enable or disable pushes for a service by default

Enable or disable pushes for a service by default
raw docstring

set-type-preferenceclj

(set-type-preference serviceId type set-enabled-input)

Override push delivery for one exact notification type

Override push delivery for one exact notification type
raw docstring

set-type-preference-with-http-infoclj

(set-type-preference-with-http-info serviceId type set-enabled-input)

Override push delivery for one exact notification type

Override push delivery for one exact notification type
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries