(get-event organizationId eventId)Get one event including metadata
Get one event including metadata
(get-event-with-http-info organizationId eventId)Get one event including metadata
Get one event including metadata
(list-events organizationId)(list-events organizationId optional-params)List a paginated inbox
List a paginated inbox
(list-events-with-http-info organizationId)(list-events-with-http-info organizationId
{:keys [service type search cursor limit]})List a paginated inbox
List a paginated inbox
(list-notification-types organizationId)(list-notification-types organizationId optional-params)List distinct notification types
List distinct notification types
(list-notification-types-with-http-info organizationId)(list-notification-types-with-http-info organizationId {:keys [serviceId]})List distinct notification types
List distinct notification types
(list-services organizationId)List services discovered from ingested events
List services discovered from ingested events
(list-services-with-http-info organizationId)List services discovered from ingested events
List services discovered from ingested events
(search-events organizationId search-events-input)Search events with a validated Boolean filter tree
Search events with a validated Boolean filter tree
(search-events-with-http-info organizationId search-events-input)Search events with a validated Boolean filter tree
Search events with a validated Boolean filter tree
(send-event send-event-input)Send an event using an application ingestion key
Send an event using an application ingestion key
(send-event-as-user organizationId send-event-input)Send an event as an authenticated user or agent
Send an event as an authenticated user or agent
(send-event-as-user-with-http-info organizationId send-event-input)Send an event as an authenticated user or agent
Send an event as an authenticated user or agent
(send-event-with-http-info send-event-input)Send an event using an application ingestion key
Send an event using an application ingestion key
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |